.\"
.\" FvwmXse - a Fvwm module interface to XSendEvent()
.\"
.\" Richard A. Guay, rag@asicint.com, 13 May 1997
.\" George Ferguson, ferguson@cs.rochester.edu, 19 Jun 1990.
.\"
.\" Version 2.0 - 13 May 1997
.\"
.TH XSE 1 "13 May 1997"
.ds ]W U of Rochester
.SH NAME
FvwmXse \- a Fvwm module interface to XSendEvent()
.SH SYNOPSIS
.na
.in +4n
.ti -4n
.B FvwmXse
.in -4n
.ad
.SH DESCRIPTION
.PP
.I FvwmXse
provides a way to send arbitrary XEvents to a window, sort of the
opposite of
.IR xev (1).
.SH OPTIONS
.PP
When FvwmXse is sent a string using SendToModule, FvwmXse will parse the string
into an event sequence and send to the proper window. The full syntax for
the string is:

SendToModule FvwmXse <window specifier> <X event string>

A window can be specified
by giving it's name, in which case the first child of the root window
whose name matches the given string will be used, or by giving it's
XID, as obtained, e.g. from
.IR xwininfo (1),
or by using one of the keywords
.IR PointerWindow ,
.IR InputFocus ,
or
.IR ClickWindow .
PointerWindow will send the event to the window that the pointer is over,
InputFocus will send it to the window with the input focus, and ClickWindow
will allow you to select the window which will receive the event by clicking
in it.
.PP
The rest of the arguments sent are taken to be
event specifiers (see below) and no tool is created. Each argument is
parsed into an event sequence which is sent to the specified window.
If no extra arguments are present, then a tool is created using the
resources in the application default file. To customize this tool, see
below under CUSTOMIZING.
.SH "SPECIFYING EVENTS"
.PP
The syntax for specifying events is modelled after that described in
Appendix B of the XToolkit Intrinsics (Xt) manual for specifying
translations. It is extended to allow more complete specification of fields
that are not needed for recognition but are useful for generation.
.PP
An event sequence is a comma-separated list of events.
.PP
An event is an optional list of modifiers, followed by an event type
description in angle brackets (`<' and `>'), followed by optional
field specifiers.
.PP
The list of modifiers is a whitespace-separated list of the following
symbols:
.na
.nf
                Shift   s               Mod1            Button1
                Lock            l               Mod2            Button2
                Ctrl            c               Mod3            Button3
                Meta            m               Mod4            Button4
                Hyper   h               Mod5            Button5
                Super   su
                Alt             a
.fi
.ad
The effect of specifying these is to inclusively-OR them into the state
field of events for which this field exists. They are ignored for other
events.
.PP
The event type should be one of the following list, which includes all
possible types of XEvent. They are described along with possible field
specifiers. Certain event types have shorthands that are also
described.  Except in keysyms and atoms, case is not significant.
Where integers are called for, they are parsed such that a leading
zero (`0') indicates octal, and a leading `0x' or `0X' indicates
hexadecimal. An XID is an integer, usually in hex.
.LP
\fIKey\fP detail x y xroot yroot
.br
\fIKeyPress\fP detail x y xroot yroot
.br
\fIKeyDown\fP detail x y xroot yroot
.br
\fIKeyRelease\fP detail x y xroot yroot
.br
\fIKeyUp\fP detail x y xroot yroot
.in +\n(INu
This sets the state field from the modifier list and sets same_screen to True.
It uses XStringToKeysym(3X) and XKeysymToKeycode(3X) to translate the
detail (a keysym) to the keycode to send.
.LP
\fICtrl\fP detail x y xroot yroot
.br
\fIShift\fP detail x y xroot yroot
.br
\fIMeta\fP detail x y xroot yroot
.in +\n(INu
These are shorthand for a
.I KeyPress
event with the appropriate modifier bit set.
.LP
\fIButtonPress\fP detail
.br
\fIBtnDown\fP detail
.br
\fIButtonRelease\fP detail
.br
\fIBtnUp\fP detail
.in +\n(INu
Sets the detail (which button) field and sets the state from the modifier
list. The same_screen field is set to True.
.LP
\fIBtn1Down\fP
.br
\fIBtn2Down\fP
.br
\fIBtn3Down\fP
.br
\fIBtn4Down\fP
.br
\fIBtn5Down\fP
.in +\n(INu
Shorthand for a
.I ButtonPress
event with the appropriate detail.
.LP
\fIBtn1Up\fP
.br
\fIBtn2Up\fP
.br
\fIBtn3Up\fP
.br
\fIBtn4Up\fP
.br
\fIBtn5Up\fP
.in +\n(INu
Shorthand for a
.I ButtonRelease
event with the appropriate detail.
.LP
\fIMotionNotify\fP detail
.br
\fIPtrMoved\fP detail
.br
\fIMotion\fP detail
.br
\fIMouseMoved\fP detail
.br
\fIBtnMotion\fP detail
.in +\n(INu
The detail should be one of
.I Normal
or
.IR Hint .
The same_screen field is set to True.
.LP
\fIBtn1Motion\fP detail
.br
\fIBtn2Motion\fP detail
.br
\fIBtn3Motion\fP detail
.br
\fIBtn4Motion\fP detail
.br
\fIBtn5Motion\fP detail
.in +\n(INu
Shorthand for a
.I MotionNotify
event with the appropriate modifier bit set.
.LP
\fIEnterNotify\fP mode detail
.br
\fIEnter\fP mode detail
.br
\fIEnterWindow\fP mode detail
.br
\fILeaveNotify\fP mode detail
.br
\fILeave\fP mode detail
.br
\fILeaveWindow\fP mode detail
.in +\n(INu
The mode should be one of
.IR Normal ,
.IR Grab ,
.IR Ungrab ,
or
.IR WhileGrabbed .
The detail can be one of
.IR Ancestor ,
.IR Virtual ,
.IR Inferior ,
.IR Nonlinear ,
.IR NonlinearVirtual ,
.IR Pointer ,
.IR PointerRoot ,
or
.IR DetailNone .
The state field is set from the modifier list and the same_screen field is
set to True.
.LP
\fIFocusIn\fP mode detail
.br
\fIFocusOut\fP mode detail
.in +\n(INu
The mode and detail should be as above.
.LP
\fIKeymapNotify\fP key_vector
.in +\n(INu
The key_vector should be a whitespace-separated list of up to thirty-two
integers representing the keyboard bitmap.
.LP
\fIExpose\fP x y width height count
.br
\fIGraphicsExpose\fP x y width height count
.br
\fIGrExp\fP x y width height count maj_code min_code
.br
\fINoExpose\fP maj_code min_code
.br
\fINoExp\fP maj_code min_code
.in +\n(INu
All field specifiers should be integers.
.LP
\fICirculateNotify\fP detail
.br
\fICirc\fP detail
.br
\fICirculateRequest\fP detail
.br
\fICircReq\fP detail
.in +\n(INu
The detail should be one of
.IR PlaceOnTop ,
.IR OnTop ,
.IR PlaceOnBottom ,
or
.IR OnBottom .
.LP
\fIConfigureNotify\fP x y width height border_width above override
.br
\fIConfigure\fP x y width height border_width above override
.br
\fIConfigureRequest\fP x y width height border_width above override
.br
\fIConfigureReq\fP x y width height border_width above override
.in +\n(INu
All fields should be integers except above which should be
an XID and override which should be a boolean.
.LP
\fICreateNotify\fP x y width height border_width override
.br
\fICreate\fP x y width height border_width override
.in +\n(INu
All fields should be integers except override which should be a
boolean.
.LP
\fIDestroyNotify\fP window
.br
\fIDestroy\fP window
.in +\n(INu
The window field should be an XID in any base.
.LP
\fIGravityNotify\fP x y
.br
\fIGrav\fP x y
.in +\n(INu
Both fields should be integers.
.LP
\fIMapNotify\fP override
.br
\fIMap\fP override
.br
\fIMapRequest\fP override
.br
\fIMapReq\fP override
.in +\n(INu
The override field should be a boolean.
.LP
\fIMappingNotify\fP request [first_keycode count]
.br
\fIMapping\fP request [first_keycode count]
.in +\n(INu
The request field should be one of
.IR Modifier ,
.IR Keyboard ,
or
.IR Pointer .
If it is
.IR Keyboard ,
then first_keycode and count should be integers.
.LP
\fIReparentNotify\fP parent x y override
.br
\fIReparent\fP parent x y override
.in +\n(INu
The parent field should be an XID, x and y should be
integers, and override should be a boolean.
.LP
\fIUnmapNotify\fP from_configure
.br
\fIUnmap\fP from_configure
.in +\n(INu
The from_configure field should be a boolean.
.LP
\fIVisibilityNotify\fP state
.br
\fIVisible\fP state
.in +\n(INu
The state field should be one of
.IR Unobscured ,
.IR PartiallyObscured ,
or
.IR FullyObscured .
.LP
\fIResizeRequest\fP width height
.br
\fIResReq\fP width height
.in +\n(INu
Both fields should be integers.
.LP
\fIClientMessage\fP message_type format data
.br
\fIMessage\fP message_type format data
.in +\n(INu
The message_type field should be an atom. The format field can be
.IR b ,
.IR c ,
.IR s ,
or
.IR l ,
in which case the data field is a whitespace-separated list of twenty bytes,
twenty characters, ten shorts or five longs respectively. These can be in
any base, except characters which are taken as is.
.LP
\fIPropertyNotify\fP atom state
.br
\fIProp\fP atom state
.in +\n(INu
The atom field should be an atom and the state field should be one of
.I NewValue
or
.IR Delete .
.LP
\fISelectionClear\fP selection
.br
\fISelClr\fP selection
.in +\n(INu
The selection field should be an atom. The time field is set to
CurrentTime.
.LP
\fISelectionRequest\fP selection target property
.br
\fISelReq\fP selection target property
.in +\n(INu
The selection and target fields should be atoms. The property field should
be an atom or the special value
.IR None .
The time field is set to CurrentTime.
.LP
\fISelectionNotify\fP selection target property
.br
\fISelect\fP selection target property
.in +\n(INu
The selection and target fields should be atoms. The property field should
be an atom or the special value
.IR None .
The time field is set to CurrentTime.
.SH EXAMPLES
.PP
To run these examples, bring up FvwmTalk to type in the examples or
bind them to a keyboard action, mouse action, or a menu.  Make sure
to preload the FvwmXse module using:
.PP
Module FvwmXse
.PP
The following command would cause the date command to be executed when a
mouse is clicked in a shell window:

.nf
.na
  SendToModule FvwmXse ClickWindow '<Key>d,<Key>a,<Key>t,<Key>e,<Key>Return'
.ad
.fi

(but see the BUGS section, below, if this is to work with
.I xterm (1)).
It could also be specified as

.nf
.na
  SendToModule FvwmXse InputFocus '<Key>d' '<Key>a' '<Key>t' '<Key>e' '<Key>Return'
.ad
.fi

and this time the events would go to the window with the keyboard focus.

.IR toplevel .
.SH ENVIRONMENT
.PP
XAPPLRESDIR                     application defaults directory
.SH FILES
.SH DIAGNOSTICS
.PP
A variety of messages can be generated if
.I FvwmXse
cannot parse an event sequence. These should give enough information
and context for debugging.  In addition, bad window specifications and
the like are flagged by the ever-popular default X mechanism of
printing lots of error messages and exiting.
.SH BUGS
.PP
FvwmXse cannot send
.I ColormapNotify
events, at least not yet.
.PP
Not really a bug, but if you are using
.I FvwmXse
to send events to an
.IR xterm (1),
make sure to enable send events using the main menu or the allowSendEvents
resource.
.PP
Also not really a bug, but note that while sending a
.I Unmap
event will cause a window to disappear, sending a
.I Map
event will not make it reappear.
.SH SEE ALSO
.PP
XSendEvent(3X),
xev(1).
.SH AUTHOR
.PP
Richard A. Guay (rag@asicint.com)
.PP
George Ferguson (ferguson@cs.rochester.edu).
